=== modified file 'HACKING'
--- HACKING	2006-09-12 19:37:02 +0000
+++ HACKING	2006-09-13 02:09:37 +0000
@@ -260,11 +260,12 @@
 Passing to other variables
 ~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-It also is bad form to pass ``ImportReplacer`` objects to other variables.
+It also is incorrect to assign ``ImportReplacer`` objects to other variables.
 Because the replacer only knows about the original name, it is unable to
 replace other variables. The ``ImportReplacer`` class will raise an
-exception if it can figure out that this happened. But it is not always
-possible to know, so bugs can be secretly waiting to be exposed.
+``IllegalUseOfScopeReplacer`` exception if it can figure out that this
+happened. But it requires accessing a member more than once from the new
+variable, so some bugs are not detected right away.
 
 
 Writing output

=== modified file 'bzrlib/lazy_import.py'
--- bzrlib/lazy_import.py	2006-09-12 23:10:13 +0000
+++ bzrlib/lazy_import.py	2006-09-13 02:09:37 +0000
@@ -17,6 +17,27 @@
 """Functionality to create lazy evaluation objects.
 
 This includes waiting to import a module until it is actually used.
+
+Most commonly, the 'lazy_import' function is used to import other modules
+in an on-demand fashion. Typically use looks like:
+    from bzrlib.lazy_import import lazy_import
+    lazy_import(globals(), '''
+    from bzrlib import (
+        errors,
+        osutils,
+        branch,
+        )
+    import bzrlib.branch
+    ''')
+
+    Then 'errors, osutils, branch' and 'bzrlib' will exist as lazy-loaded
+    objects which will be replaced with a real object on first use.
+
+    In general, it is best to only load modules in this way. This is because
+    it isn't safe to pass these variables to other functions before they
+    have been replaced. This is especially true for constants, sometimes
+    true for classes or functions (when used as a factory, or you want
+    to inherit from them).
 """
 
 import re

